##  INTEGRATION_RUN_STARTED (ServiceNow Integration)

```
{
  "version": "?",
  "type": "SERVICENOW",
  "scope": "PARTIAL",
  "errorCount": 1,
  "warningCount": 2,
  "processedCount": 3,
  "duration": "PT0.123S",
  "progress": "RUNNING",
  "synchronizationId": "18886403-3edb-483d-a13f-cac5f4b34802"
}
```



